@@ -1,29 +1,57 @@
-# load function for "MDplot_clusters_timeseries"
+# loading function for "clusters_ts()"
 load_clusters_ts <- function( path,
                               lengths,
                               names = NA,
                               mdEngine = "GROMOS" )
 {
-  
-  # read input and get rid of column 2, which is unnecessary and pack everything in a list
-  # of lists, where the first element is the name of the trajectory and the second is the
-  # list of clusterIDs between the boundaries specified by the lengths of every trajectory
-  TABLE_buf <- read.table( path )[ , -2 ]
+  mdEngine <- toupper( mdEngine )
+  if( mdEngine != "GROMOS" &&
+      mdEngine != "GROMACS" &&
+      mdEngine != "AMBER" )
+    stop( paste( "The specified 'mdEngine', set to ", mdEngine, " is unknown.", sep = "" ) )
+
   LIST_return <- list()
-  INT_startLine <- 1  
   if( all( is.na( names ) ) ||
       length( lengths ) != length( names ) )
     names <- sapply( seq( 1, length( lengths ) ),
-                         function( x ) paste( "trajectory",
-                                              x,
-                                              sep = "" ) )
-  for( i in 1:length( lengths ) )
+                     function( x ) paste( "trajectory",
+                                          x,
+                                          sep = "" ) )
+
+  if( mdEngine == "GROMOS" )
   {
-    LIST_return[[ length( LIST_return ) + 1 ]] <- list( names[ i ], TABLE_buf[ INT_startLine:( INT_startLine + ( lengths[ i ] - 1 ) ),
-                                                                               2 ] )
-    INT_startLine <- INT_startLine + lengths[ i ]
+    # read input and get rid of column 2, which is unnecessary and pack everything in a list
+    # of lists, where the first element is the name of the trajectory and the second is the
+    # list of clusterIDs between the boundaries specified by the lengths of every trajectory
+    TABLE_buf <- read.table( path )[ , -2 ]
+    INT_startLine <- 1  
+    for( i in 1:length( lengths ) )
+    {
+      LIST_return[[ length( LIST_return ) + 1 ]] <- list( names[ i ], TABLE_buf[ INT_startLine:( INT_startLine + ( lengths[ i ] - 1 ) ),
+                                                                                 2 ] )
+      INT_startLine <- INT_startLine + lengths[ i ]
+    }
+  }
+  if( mdEngine == "GROMACS" )
+  {
+    LIST_temp <- load_clusters_GROMACS( path, lengths )
+    for( i in 1:length( LIST_temp ) )
+      LIST_return[[ length( LIST_return ) + 1 ]] <- list( names[ i ], unlist( LIST_temp[[ i ]][ , 2 ] ) )
+  }
+  if( mdEngine == "AMBER" )
+  {
+    TABLE_buf <- read.table( path )
+    INT_startLine <- 1  
+    for( i in 1:length( lengths ) )
+    {
+      TABLE_traj <- TABLE_buf[ INT_startLine:( INT_startLine + ( lengths[ i ] - 1 ) ),
+                               2 ]
+      TABLE_traj[ TABLE_traj == -1 ] <- 0
+      LIST_return[[ length( LIST_return ) + 1 ]] <- list( names[ i ],
+                                                          TABLE_traj )
+      INT_startLine <- INT_startLine + lengths[ i ]
+    }
   }
-  #########
   return( LIST_return )
 }
 
@@ -157,46 +185,145 @@ clusters_ts <- function( clustersDataTS,
   #########
   
   # plot the coloured lines representing the cluster occurences over time here
-  if( length( clustersDataTS ) > 1 )
+  for( i in 1:length( clustersDataTS ) )
   {
-    for( i in 1:length( clustersDataTS ) )
+    VEC_trajOccurences <- c()
+    VEC_clusterIDs <- unlist( clustersDataTS[[ i ]][[ 2 ]] )
+    VEC_xTicks <- seq( 1, length( clustersDataTS[[ i ]][[ 2 ]] ) )
+    for( j in 1:clustersNumber )
     {
-      VEC_trajOccurences <- c()
-      VEC_clusterIDs <- unlist( clustersDataTS[[ i ]][[ 2 ]] )
-      VEC_xTicks <- seq( 1, length( clustersDataTS[[ i ]][[ 2 ]] ) )
-      for( j in 1:clustersNumber )
-      {
-        segments( VEC_xTicks[ VEC_clusterIDs == j ],
-                  rep( i - 0.425, length( VEC_xTicks[ VEC_clusterIDs == j ] ) ),
-                  VEC_xTicks[ VEC_clusterIDs == j ],
-                  rep( i + 0.425, length( VEC_xTicks[ VEC_clusterIDs == j ] ) ),
-                  lwd = 0.65,
-                  col = COLOURS_clusters[ j ] )
-        VEC_trajOccurences <- c( VEC_trajOccurences,
-                                 length( VEC_clusterIDs[ VEC_clusterIDs == j ] ) / length( VEC_clusterIDs ) * 100 )
-      }
-      MAT_printResults <- rbind( MAT_printResults,
-                                 setNumberDigits( VEC_trajOccurences,
-                                                  2 ) )
+      segments( VEC_xTicks[ VEC_clusterIDs == j ],
+                rep( i - 0.425, length( VEC_xTicks[ VEC_clusterIDs == j ] ) ),
+                VEC_xTicks[ VEC_clusterIDs == j ],
+                rep( i + 0.425, length( VEC_xTicks[ VEC_clusterIDs == j ] ) ),
+                lwd = 0.65,
+                col = COLOURS_clusters[ j ] )
+      VEC_trajOccurences <- c( VEC_trajOccurences,
+                               length( VEC_clusterIDs[ VEC_clusterIDs == j ] ) / length( VEC_clusterIDs ) * 100 )
     }
-    rownames( MAT_printResults ) <- c( "overall",
-                                       unlist( lapply( clustersDataTS, function( x ) x[[ 1 ]] ) ) )
+    MAT_printResults <- rbind( MAT_printResults,
+                               setNumberDigits( VEC_trajOccurences,
+                                                2 ) )
   }
+  rownames( MAT_printResults ) <- c( "overall",
+                                     unlist( lapply( clustersDataTS, function( x ) x[[ 1 ]] ) ) )
   #########
   
   return( MAT_printResults )
 }
 
-# load function for "MDplot_clusters"
+# load input for GROMACS
+load_clusters_GROMACS <- function( path,
+                                   lengths )
+{
+  inputData <- readLines( path )
+  VEC_times <- c()
+  VEC_clusters <- c()
+  for( i in 1:length( inputData ) )
+  {
+    if( substr( inputData[ i ], 1, 5 ) == "@TYPE" )
+    {
+      for( j in ( i + 1 ):length( inputData ) )
+      {
+        if( substr( inputData[ j ], 1, 1 ) != "@" )
+        {
+          for( k in j:length( inputData ) )
+          {
+            VEC_curLine <- unlist( strsplit( inputData[ k ], " +" ) )
+            VEC_clusters <- c( VEC_clusters, as.numeric( VEC_curLine[ 3 ] ) )
+            VEC_times <- c( VEC_times, as.numeric( VEC_curLine[ 2 ] ) )
+          }
+          MAT_input <- matrix( c( VEC_times,
+                                  VEC_clusters ),
+                                  ncol = 2,
+                               byrow = FALSE )
+          LIST_temp <- NULL
+          if( all( !is.na( lengths ) ) )
+          {
+            if( sum( lengths ) != nrow( MAT_input ) )
+              stop( "The sum of lengths must be the same as the number of lines in the input!" )
+            INT_lastBegin <- 1
+            for( k in 1:length( lengths ) )
+            {
+              LIST_temp[[ length( LIST_temp ) + 1 ]] <- MAT_input[ INT_lastBegin:( INT_lastBegin +
+                                                                                   lengths[ k ] -
+                                                                                   1 ),
+                                                                   ,
+                                                                   drop = FALSE ]
+              INT_lastBegin <- lengths[ k ] + 1
+            }
+          }
+          else
+            LIST_temp <- list( MAT_input )
+          return( LIST_temp )
+        }
+      }
+    }
+  }
+}
+
+# loading function for "clusters()"
 load_clusters <- function( path,
                            names = NA,
+                           lengths = NA,
                            mdEngine = "GROMOS" )
 {
-  
-  # load and transpose matrix
-  MAT_pre <- as.matrix( read.table( path ) )[ , -1  ]
-  MAT_pre <- MAT_pre[ , ( ( ncol( MAT_pre ) / 2 ) + 1 ):ncol( MAT_pre ) ]
-  MAT_pre <- t( MAT_pre )
+  mdEngine <- toupper( mdEngine )
+  if( mdEngine != "GROMOS" &&
+      mdEngine != "GROMACS" &&
+      mdEngine != "AMBER" )
+    stop( paste( "The specified 'mdEngine', set to ", mdEngine, " is unknown.", sep = "" ) )
+  MAT_pre <- NULL
+  if( mdEngine == "GROMOS" )
+  {
+    # load and transpose matrix
+    MAT_pre <- as.matrix( read.table( path ) )[ , -1  ]
+    MAT_pre <- MAT_pre[ , ( ( ncol( MAT_pre ) / 2 ) + 1 ):ncol( MAT_pre ) ]
+    MAT_pre <- t( MAT_pre )
+  }
+  if( mdEngine == "GROMACS" )
+  {
+    LIST_temp <- load_clusters_GROMACS( path, lengths )
+    INT_numberClusters <- max( unlist( lapply( LIST_temp,
+                                               FUN = function( x ) max( unlist( x[ , 2 ] ) ) ) ) )
+    MAT_pre <- matrix( rep( 0, times = INT_numberClusters * length( LIST_temp ) ),
+                       nrow = length( LIST_temp ) )
+    for( i in 1:length( LIST_temp ) )
+      for( j in 1:INT_numberClusters )
+        MAT_pre[ i, j ] <- sum( LIST_temp[[ i ]][ , 2 ] == j )
+  }
+  if( mdEngine == "AMBER" )
+  {
+    # read comment line and the input table
+    CON_input <- file( path, open = "r" )
+    VEC_commentLine <- NA
+    while( length( STRING_theLine <- readLines( CON_input, n = 1, warn = FALSE ) ) > 0 )
+    {
+      VEC_commentLine <- unlist( strsplit( STRING_theLine, split = " +" ) )
+      if( VEC_commentLine[ 1 ] == "#Cluster" )
+        break
+    }
+    close( CON_input )
+    TABLE_input <- read.table( path )
+
+    # depending on input, generate output matrix and decide on processing
+    MAT_pre <- matrix( rep( 0, times = nrow( TABLE_input ) ),
+                       nrow = 1 )
+    if( "NumIn1st" %in% VEC_commentLine )
+    {
+      # more than one trajectories
+      VEC_indices <- grep( "NumIn", VEC_commentLine )
+      for( i in 1:length( VEC_indices ) )
+        MAT_pre <- rbind( MAT_pre,
+                          TABLE_input[ , VEC_indices[ i ] ] )
+      MAT_pre <- MAT_pre[ -1, ]
+    }
+    else
+    {
+      # only one trajectory
+      MAT_pre[ 1, ] <- TABLE_input[ , 2 ]
+    }
+  }
   if( all( !is.na( names ) ) &&
       length( names ) == nrow( MAT_pre ) )
   {
@@ -219,7 +346,7 @@ clusters <- function( clusters,
 {
   # reduce number of clusters, in case specified and take care of the trajectory names
   if( !is.na( clustersNumber ) )
-    clusters <- clusters[ , 1:clustersNumber ]
+    clusters <- clusters[ , 1:clustersNumber, drop = FALSE ]
   colnames( clusters ) <- 1:ncol( clusters )
   #########
   
